@@ -1,23 +1,26 @@
 # This file contains functions that operate on Redis 'hash' values.
 
-redisHGet <- function(key, field, raw=FALSE) {
-  if(raw){
-    .redisRawCmd(.raw('HGET'), .raw(key), .raw(field))
-  }else{
-    .redisCmd(.raw('HGET'), .raw(key), .raw(field))
-  }
+redisHGet <- function(key, field, ...)
+{
+  .redisCmd(.raw('HGET'), .raw(key), .raw(field),...)
 }
 
-redisHSet <- function(key, field, value, NX=FALSE) {
+redisHSet <- function(key, field, value, NX=FALSE)
+{
   value <- .cerealize(value)
   cmd <- 'HSET'
   if(NX) cmd <- 'HSETNX'
   .redisCmd(.raw(cmd), .raw(key), .raw(field), value)
 }
 
-redisHIncrBy <- function(key, field, value)
+redisHIncrBy <- function(key, field, value, ...)
 {
-  .redisCmd(.raw('HINCRBY'),.raw(key),.raw(field),.raw(as.character(value)))
+  .redisCmd(.raw('HINCRBY'),.raw(key),.raw(field),.raw(as.character(value)),...)
+}
+
+redisHIncrByFloat <- function(key, field, value, ...)
+{
+  .redisCmd(.raw('HINCRBY'),.raw(key),.raw(field),.raw(as.character(value)),...)
 }
 
 redisHExists <- function(key, field)
@@ -35,25 +38,25 @@ redisHLen <- function(key)
   .redisCmd(.raw('HLEN'), .raw(key))
 }
 
-redisHFields <- function(key)
+redisHFields <- function(key,...)
 {
-  .redisCmd(.raw('HKEYS'), .raw(key))
+  .redisCmd(.raw('HKEYS'), .raw(key),...)
 }
 
-redisHKeys <- function(key)
+redisHKeys <- function(key,...)
 {
-  redisHFields(key)
+  redisHFields(key,...)
 }
 
-redisHVals <- function(key)
+redisHVals <- function(key,...)
 {
-  .redisCmd(.raw('HVALS'), .raw(key))
+  .redisCmd(.raw('HVALS'), .raw(key),...)
 }
 
-redisHGetAll <- function(key)
+redisHGetAll <- function(key,...)
 {
   retval <- NULL
-  all <- .redisCmd(.raw('HGETALL'), .raw(key))
+  all <- .redisCmd(.raw('HGETALL'), .raw(key),...)
   if(!is.null(all) && length(all)>1) {
     retval <- all[seq(2,length(all),by=2)]
     names(retval) <- all[seq(1,length(all),by=2)]
@@ -61,8 +64,8 @@ redisHGetAll <- function(key)
   retval
 }
 
-redisHMGet <- function(key, fields) {
-  a <- c(alist(),list(.raw('HMGET')))
+redisHMGet <- function(key, fields, ...) {
+  a <- c(alist(),list(.raw('HMGET')),...)
   a <- c(a, lapply(c(key,fields), charToRaw))
   retval <- do.call('.redisCmd', a)
   if(length(retval) == length(fields)) names(retval) <- fields
